"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isRequested = exports.isReceived = exports.isFailed = exports.isExpired = exports.extractError = exports.extractData = exports.createRequested = exports.createReceived = exports.createFailed = void 0;

var S = _interopRequireWildcard(require("./statuses"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

/**
 * Create an object representing failed resource.
 *
 * @param {number|string} id
 * @param {*} error
 * @returns {{error: *, id: (number|string), status: string, timestamp: number}}
 */
var createFailed = function createFailed(id, error) {
  return {
    error: error,
    id: id,
    status: S.FAILED,
    timestamp: Date.now()
  };
};
/**
 * Create an object representing received resource.
 *
 * @param {number|string} id
 * @param {*} data
 * @returns {{data: *, id: (number|string), status: string, timestamp: number}}
 */


exports.createFailed = createFailed;

var createReceived = function createReceived(id, data) {
  return {
    data: data,
    id: id,
    status: S.RECEIVED,
    timestamp: Date.now()
  };
};
/**
 * Create an object representing requested resource.
 *
 * @param {number|string} id
 * @returns {{id: (number|string), status: string}}
 */


exports.createReceived = createReceived;

var createRequested = function createRequested(id) {
  return {
    id: id,
    status: S.REQUESTED
  };
};
/**
 * Extract data from the object representing resource.
 *
 * @param {Object} resource
 * @returns {*}
 */


exports.createRequested = createRequested;

var extractData = function extractData(resource) {
  return resource && resource.data ? resource.data : undefined;
};
/**
 * Extract error from the object representing resource.
 *
 * @param {Object} resource
 * @returns {*}
 */


exports.extractData = extractData;

var extractError = function extractError(resource) {
  return resource && resource.error ? resource.error : undefined;
};
/**
 * Check if resource is expired.
 *
 * @param {Object} resource
 * @param {number} ttl
 * @returns {boolean}
 */


exports.extractError = extractError;

var isExpired = function isExpired(resource, ttl) {
  return !!(resource && resource.timestamp && Date.now() > resource.timestamp + ttl);
};
/**
 * Check if resource is failed.
 *
 * @param {Object} resource
 * @returns {boolean}
 */


exports.isExpired = isExpired;

var isFailed = function isFailed(resource) {
  return !!(resource && resource.status === S.FAILED);
};
/**
 * Check if resource is received.
 *
 * @param {Object} resource
 * @returns {boolean}
 */


exports.isFailed = isFailed;

var isReceived = function isReceived(resource) {
  return !!(resource && resource.status === S.RECEIVED);
};
/**
 * Check if resource is requested.
 *
 * @param {Object} resource
 * @returns {boolean}
 */


exports.isReceived = isReceived;

var isRequested = function isRequested(resource) {
  return !!(resource && resource.status === S.REQUESTED);
};

exports.isRequested = isRequested;